==> jquery-validation-unobtrusive-3.2.33.tgz: jquery-validation-unobtrusive/README.md <==
# Installation
> `npm install --save @types/jquery-validation-unobtrusive`

# Summary
This package contains type definitions for Microsoft jQuery Unobtrusive Validation (https://github.com/aspnet/jquery-validation-unobtrusive).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-validation-unobtrusive.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-validation-unobtrusive/index.d.ts)
````ts
// Type definitions for Microsoft jQuery Unobtrusive Validation v3.2.3
// Project: https://github.com/aspnet/jquery-validation-unobtrusive
// Definitions by: Matt Brooks <https://github.com/EnableSoftware>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery.validation" />

declare namespace MicrosoftJQueryUnobtrusiveValidation {
    type JQuerySelector = string | Document | Element | JQuery;

    interface Adapter {
        name: string;
        params: string[];
        adapt: Function;
    }

    interface Adapters extends Array<Adapter> {
        add(adapterName: string, fn: Function): Adapters;
        add(adapterName: string, params: string[], fn: Function): Adapters;
        addMinMax(
            adapterName: string,
            minRuleName: string,
            maxRuleName: string,
            minMaxRuleName: string,
            minAttribute?: string,
            maxAttribute?: string,
        ): Adapters;
        addSingleVal(adapterName: string, ruleName: string): Adapters;
        addSingleVal(adapterName: string, attribute: string, ruleName: string): Adapters;
        addBool(adapterName: string, ruleName?: string): Adapters;
        addMethod(adapterName: string, fn: (value: string, element: Element, params: any) => any): Adapters;
    }

    interface Validator {
        adapters: Adapters;
        parseElement(element: JQuerySelector, skipAttach?: boolean): void;
        parse(selector: JQuerySelector): void;
    }
}

declare namespace JQueryValidation {
    interface ValidatorStatic {
        unobtrusive: MicrosoftJQueryUnobtrusiveValidation.Validator;
    }
}

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 20:36:37 GMT
 * Dependencies: [@types/jquery.validation](https://npmjs.com/package/@types/jquery.validation)
 * Global values: none

# Credits
These definitions were written by [Matt Brooks](https://github.com/EnableSoftware).

==> jquery-validation-unobtrusive-3.2.34.tgz: jquery-validation-unobtrusive/README.md <==
# Installation
> `npm install --save @types/jquery-validation-unobtrusive`

# Summary
This package contains type definitions for jquery-validation-unobtrusive (https://github.com/aspnet/jquery-validation-unobtrusive).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-validation-unobtrusive.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-validation-unobtrusive/index.d.ts)
````ts
/// <reference types="jquery.validation" />

declare namespace MicrosoftJQueryUnobtrusiveValidation {
    type JQuerySelector = string | Document | Element | JQuery;

    interface Adapter {
        name: string;
        params: string[];
        adapt: Function;
    }

    interface Adapters extends Array<Adapter> {
        add(adapterName: string, fn: Function): Adapters;
        add(adapterName: string, params: string[], fn: Function): Adapters;
        addMinMax(
            adapterName: string,
            minRuleName: string,
            maxRuleName: string,
            minMaxRuleName: string,
            minAttribute?: string,
            maxAttribute?: string,
        ): Adapters;
        addSingleVal(adapterName: string, ruleName: string): Adapters;
        addSingleVal(adapterName: string, attribute: string, ruleName: string): Adapters;
        addBool(adapterName: string, ruleName?: string): Adapters;
        addMethod(adapterName: string, fn: (value: string, element: Element, params: any) => any): Adapters;
    }

    interface Validator {
        adapters: Adapters;
        parseElement(element: JQuerySelector, skipAttach?: boolean): void;
        parse(selector: JQuerySelector): void;
    }
}

declare namespace JQueryValidation {
    interface ValidatorStatic {
        unobtrusive: MicrosoftJQueryUnobtrusiveValidation.Validator;
    }
}

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 05:47:07 GMT
 * Dependencies: [@types/jquery.validation](https://npmjs.com/package/@types/jquery.validation)

# Credits
These definitions were written by [Matt Brooks](https://github.com/EnableSoftware).
